/* dialog.c
 * Part of the RTAudio.Client project
 * Contains version info, how to use info, etc...
 * Written by Electronic One <dkaye@cyberspc.mb.ca>
 */

#include "version.h"
#include "errorcodes.h"
#include "screen.h"
#include "modes.h"
#include "switches.h"
#include "exit.h"

#include "curses.h"
#include "panel.h"
#include "form.h"
#include "menu.h"
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

void n_show_ver(void)
{
   curs_set(0);  /* Make cursor invisible */
   bkgdset(get_color(COLOR_BLACK, COLOR_WHITE));
   clear();
   bkgdset(A_BOLD|get_color(COLOR_WHITE, COLOR_WHITE));
   attrset(A_BOLD|get_color(COLOR_WHITE, COLOR_WHITE));
   border(179, 179, 196, 196, 218, 191, 192, 217);
   bkgdset(get_color(COLOR_BLUE, COLOR_WHITE));
   attrset(get_color(COLOR_BLUE, COLOR_WHITE));
   mvaddstr(1, 22, "Realtime Audio Multipurpose Program");
   bkgdset(get_color(COLOR_BLACK, COLOR_WHITE));
   attrset(get_color(COLOR_BLACK, COLOR_WHITE));
   mvprintw(4, 10, "RAMP version %s -> %s.", RTA_VERSION, RTA_DATE);
   mvaddstr(5, 10, "Written by Electronic One <eo@autobahn.mb.ca>");
   mvaddstr(8, 10, "GSM audio compression algorithm:");
   mvaddstr(9, 10, "Copyright 1992 by Jutta Degener and Carsten Bormann,");
   mvaddstr(10, 10, "Technische Universitaet Berlin.");
   mvaddstr(13, 10, "Developed using:");
   mvaddstr(14, 10, "SlackWare version 3.0.0");
   mvaddstr(15, 10, "kernel    version 2.0.3");
   mvaddstr(16, 10, "gcc       version 2.7.0");
   mvaddstr(17, 10, "gsm       version 1.0.9");
   mvaddstr(18, 10, "libc      version 4.7.2");
   mvaddstr(19, 10, "ncurses   version 1.9.9e");
   mvaddstr(stdscr->_maxy, 25, "> Press any key to continue <");
   attrset(get_color(COLOR_RED, COLOR_WHITE));
   mvaddstr(21, 20, "NCURSES MODE IS UNDER SEVERE DEVELOPMENT");
   mvaddstr(22, 20, "NCURSES MODE RELEASED ONLY AS A PREVIEW!");
   refresh();
   getch();
}

void t_show_ver(void)
{
   printf("\n");
   printf("RAMP version %s -> %s.\n", RTA_VERSION, RTA_DATE);
   printf("Written by Electronic One <eo@autobahn.mb.ca>.\n");
   printf("GSM audio compression algorithm:\n");
   printf("Copyright 1992 by Jutta Degener and Carsten Bormann,\n");
   printf("Technische Universitaet Berlin.\n");
   printf("Developed using:\n");
   printf("SlackWare version 3.0.0\n");
   printf("kernel    version 2.0.3\n");
   printf("gcc       version 2.7.0\n");
   printf("gsm       version 1.0.9\n");
   printf("libc      version 4.7.2\n");
   printf("ncurses   version 1.9.9e\n");
}

void n_show_help(void)
{
   bkgd(get_color(COLOR_BLACK, COLOR_WHITE));
   attrset(get_color(COLOR_BLACK, COLOR_WHITE));
   clear();
   border(186, 186, 205, 205, 201, 187, 200, 188);
   mvaddstr(1, 2, "Usage: ramp [-c host|-i file] [-v] [-h] [-o file]");
   mvaddstr(2, 2, "  -c : Connect to and read from host 'host'");
   mvaddstr(3, 2, "  -i : Read from file 'file', use 'std' to represent stdin");
   mvaddstr(4, 2, "  -o : Write to file 'file', use 'std' to represent stdout");
   mvaddstr(5, 2, "  -v : Show version");
   mvaddstr(6, 2, "  -h : Show this help");
   mvaddstr(7, 2, "NOTE : To use in ncurses mode, specify no arguments.");
   mvaddstr(9, 2, "Press any key to continue...");
   getch();
}

void t_show_help(void)
{
   printf("\n");
   printf("Usage: ramp [-c host|-i file] [-v] [-h] [-o file]\n");
   printf("  -c : Connect to and read from host 'host'\n");
   printf("  -i : Read from file 'file', use 'std' to represent stdin\n");
   printf("  -o : Write to file 'file', use 'std' to represent stdout\n");
   printf("  -v : Show version\n");
   printf("  -h : Show this help\n");
   printf("NOTE : To use in ncurses mode, specify no arguments.\n");
}

int generic_key_processor(int c)
{
   switch(c)
     {
      case KEY_BACKSPACE:
	return REQ_DEL_PREV;
      case KEY_HOME:
	return REQ_BEG_FIELD;
      case KEY_END:
	return REQ_END_FIELD;
      case KEY_LEFT:
	return REQ_LEFT_CHAR;
      case KEY_RIGHT:
	return REQ_RIGHT_CHAR;
      default: return c;
     }
}

char *get_value(int y, int x, char *msg, int Len)
{
   WINDOW *w=NULL, *sub=NULL;
   FORM *form;
   FIELD *f[2];
   int width, c, i;
   char *value, quit = 0;
   
   width = (strlen(msg) > Len) ? strlen(msg) : Len;
   
   if(
      ((value = (char *) malloc(Len + 1)) == NULL) ||
      ((w = newwin(6, width + 4, y, x)) == NULL) ||
      ((sub = derwin(w, 1, Len, 3, 2)) == NULL)
     )
     {
	perror("Insifficient memory");
	n_exit(NO_MEM);
     }

   bzero(value, Len + 1);

   f[0] = new_field(1, Len, 0, 0, 0, 0);
   f[1] = (FIELD *) NULL;

   set_field_fore(f[0], A_BOLD|get_color(COLOR_WHITE, COLOR_BLUE));
   set_field_back(f[0], A_BOLD|get_color(COLOR_WHITE, COLOR_BLUE));
   field_opts_off(f[0], O_WRAP|O_AUTOSKIP);
   field_opts_on(f[0], O_STATIC);
   set_max_field(f[0], Len);

   form = new_form(f);
   
   set_form_win(form, w);
   set_form_sub(form, sub);
   form_driver(form, REQ_INS_MODE);

   wbkgd(w, A_BOLD|get_color(COLOR_YELLOW, COLOR_BLACK));

   wborder(w, 186, 186, 205, 205, 201, 187, 200, 188);

   wattrset(w, A_BOLD|get_color(COLOR_WHITE, COLOR_BLACK));
   
   mvwaddstr(w, 1, 2, msg);

   post_form(form);
   
   curs_set(1);
      
   wrefresh(w); 
   
   keypad(w, TRUE);
   
   cbreak();   
   
   do
     {
	c = wgetch(w);
	if(c == 13)
	  quit = 1;
	else
	  form_driver(form, generic_key_processor(c));
	wrefresh(sub);
     }
   while(!quit);
   
   curs_set(0);
   
   mvwinnstr(sub, 0, 0, value, Len);
   
   for(i=0; i <= Len; ++i)
     {
	if(value[i] == 32)
	  {
	     value[i] = 0;
	     break;
	  }
     }
   
   curs_set(0);
   delwin(w);
   free(sub);
   free_form(form);
   refresh();
      
   return value;
}

char *center_get_value(char *msg, int Len)
{
   int width = (strlen(msg) > Len) ? strlen(msg) : Len;
   
   return get_value(((stdscr->_maxy / 2) + 1),
		    ((stdscr->_maxx / 2) - ((width + 4) / 2)),
		    msg,
		    Len);

}

WINDOW *message(int y, int x, char *msg)
{
   WINDOW *w;
   
   if((w = newwin(3, strlen(msg) + 4, y, x)) == NULL)
     return NULL;
   else
     {
	wbkgd(w, A_BOLD|get_color(COLOR_YELLOW, COLOR_BLACK));
	wborder(w, 186, 186, 205, 205, 201, 187, 200, 188);
	wattrset(w, A_BOLD|get_color(COLOR_WHITE, COLOR_BLACK));
	mvwaddstr(w, 1, 2, msg);
	wrefresh(w);
     }
   
   return w;
}

WINDOW *center_message(char *msg)
{
   return message(((stdscr->_maxy / 2) + 1),
		  ((stdscr->_maxx / 2) - ((strlen(msg) + 4) / 2)),
		  msg);
}

void dump_host_info(SW *sw, const char *name, const char *address)
{
   long temp2;
   char *temp = (char *) &temp2, i;
   
   temp2 = (long) *((long *) address);

   switch(sw->mode)
     {
      case MODE_TEXT:
	printf("Official host name and IP address: %s, ", name);
	for(i=0; i < 4; ++i)
	  printf("%u.", (unsigned char) temp[i]);
	printf("\n");
	break;
      case MODE_NCURSES:
	break;
     }
   
}

/*
char *choose_input(int x, int y, char *msg)
{
   WINDOW *w;
   WINDOW *sub;
   char *choice;
   char *input_choices[] = {"Host", "File", "Quit", (char *) NULL};
   ITEM *items[sizeof(input_choices)/sizeof(char *)];
   MENU *m;
   ITEM **ip = items;
   int mrows, mcols;
   int width;
   
   width = (strlen(msg) > 4) ? (strlen(msg) + 4) : 8;
   
   
   return choice;
}
*/


